@@ -1,44 +1,3 @@
-# Author(s) : Athul Pradeepkumar Girija; apradee@purdue.edu
-#
-# License : CC-BY-SA-4.0
-#
-# You are free to:
-#
-# Share — copy and redistribute the material in any medium or format
-# Adapt — remix, transform, and build upon the material for any#
-# purpose,  even commercially.
-
-# The licensor cannot revoke these freedoms as long as you follow the 
-# license terms
-
-# Attribution — You must give appropriate credit, provide a link to 
-# the license, and indicate if changes were made. You may do so in any
-# reasonable manner, but not in any way that suggests the licensor 
-# endorses you or your use.
-
-# ShareAlike — If you remix, transform, or build upon the material, 
-# you must distribute your contributions under the same license as 
-# the original.  
-
-# The above copyright notice and this permission notice shall be 
-# included in all copies or substantial portions of the Software.
-
-# ===================================================================
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
-# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
-# NONINFRINGEMENT. 
-
-# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
-# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
-# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
-# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-# ===================================================================
-
-# This script requires that `numpy`, 'scipy', and ''matplotlib
-# be installed within  the Python environment you are running 
-# this script in.
-
 import numpy as np
 from scipy.interpolate import interp1d
 from matplotlib import rcParams
@@ -72,6 +31,10 @@ class Planet:
 		zonal harmonic coefficient J2
 	J3 : float
 		zonal harmonic coefficient J3
+	a0 : float
+		right ascension of North Pole in ICRF, rad
+	d0 : float
+		declination of North Pole in ICRF, rad
 	h_thres : float
 		Atmospheric model cutoff altitude in meters, 
 		density is set to 0, if altitude exceeds h_thres
@@ -137,7 +100,9 @@ class Planet:
 			self.rho0   = 64.790       
 			self.CPCV   = 1.289        
 			self.J2     = 4.458E-6     
-			self.J3     = 0.000000    
+			self.J3     = 0.000000
+			self.a0 = 272.76 * np.pi / 180.0
+			self.d0 = 67.16 * np.pi / 180.0
 			self.h_thres= 180000.0     
 			self.h_skip = 180000.0     
 			self.h_trap = 10000.0
@@ -152,7 +117,9 @@ class Planet:
 			self.rho0   = 1.2250       
 			self.CPCV   = 1.4          
 			self.J2     = 1082.6E-6    
-			self.J3     = -2.532E-6    
+			self.J3     = -2.532E-6
+			self.a0 = 0.0 * np.pi / 180.0
+			self.d0 = 90.0 * np.pi / 180.0
 			self.h_thres= 120.0E3      
 			self.h_skip = 120.0E3      
 			self.h_trap = 10.0E3
@@ -167,7 +134,9 @@ class Planet:
 			self.rho0   = 0.0200       
 			self.CPCV   = 1.289        
 			self.J2     = 1960.45E-6   
-			self.J3     = 31.5E-6      
+			self.J3     = 31.5E-6
+			self.a0 = 317.68143 * np.pi / 180.0
+			self.d0 = 52.88650 * np.pi / 180.0
 			self.h_thres= 120.0E3      
 			self.h_skip = 120.0E3      
 			self.h_trap = 10.0E3 
@@ -182,8 +151,10 @@ class Planet:
 			self.rho0   = 0.16288        
 			self.CPCV   = 1.4348         
 			self.J2     = 14736E-6      
-			self.J3     = 0.0            
-			self.h_thres= 1000.0E3     
+			self.J3     = 0.0
+			self.a0 = 268.056595 * np.pi / 180.0
+			self.d0 = 64.495303 * np.pi / 180.0
+			self.h_thres= 1000.0E3
 			self.h_skip = 1000.0E3     
 			self.h_trap = 50.0E3 
 
@@ -195,7 +166,9 @@ class Planet:
 			self.rho0   = 0.19847      
 			self.CPCV   = 1.4348       
 			self.J2     = 16298E-6     
-			self.J3     = 0.0          
+			self.J3     = 0.0
+			self.a0 = 40.589 * np.pi / 180.0
+			self.d0 = 83.537 * np.pi / 180.0
 			self.h_thres= 1000.0E3     
 			self.h_skip = 1000.0E3     
 			self.h_trap = 50.0E3      
@@ -209,7 +182,9 @@ class Planet:
 			self.rho0   = 5.43500       
 			self.CPCV   = 1.400         
 			self.J2     = 31.808E-6     
-			self.J3     = -1.880E-6     
+			self.J3     = -1.880E-6
+			self.a0 = 39.4827 * np.pi / 180.0
+			self.d0 = 83.4279 * np.pi / 180.0
 			self.h_thres= 1000.0E3      
 			self.h_skip = 1000.0E3      
 			self.h_trap = 30.0E3
@@ -225,7 +200,9 @@ class Planet:
 			self.rho0   = 0.3788        
 			self.CPCV   = 1.450         
 			self.J2     = 3343.3E-6     
-			self.J3     = 0.000000      
+			self.J3     = 0.000000
+			self.a0 = 257.311 * np.pi / 180.0
+			self.d0 = -15.175 * np.pi / 180.0
 			self.h_thres= 1500.0E3      
 			self.h_skip = 1500.0E3      
 			self.h_trap = 50.0E3
@@ -240,22 +217,25 @@ class Planet:
 			self.rho0   = 0.44021       
 			self.CPCV   = 1.450         
 			self.J2     = 3411.0E-6     
-			self.J3     = 0.000000      
+			self.J3     = 0.000000
+			self.a0 = 299.36 * np.pi / 180.0
+			self.d0 = 43.36 * np.pi / 180.0
 			self.h_thres= 1000.0E3      
 			self.h_skip = 1000.0E3      
 			self.h_trap = 10.0E3
 			self.h_low  = 100.0E3        
 
 		else:
-			print(" >>> ERR : Invalid planet identifier provided.")
+			raise ValueError(" >>> ERR : Invalid planet identifier provided.")
 			print("Valid entries are: VENUS, EARTH, MARS, \
 			JUPITER, SATURN, TITAN, URANUS, NEPTUNE")
 
-		# compute reference values
-		self.Vref      = np.sqrt(self.GM/self.RP)     
-		self.tau       = self.RP / self.Vref          
-		self.OMEGAbar  = self.OMEGA*self.tau          
-		self.EARTHG    = 9.80665                      
+		# compute reference values for planet
+		if self.ID:
+			self.Vref      = np.sqrt(self.GM/self.RP)
+			self.tau       = self.RP / self.Vref
+			self.OMEGAbar  = self.OMEGA*self.tau
+			self.EARTHG    = 9.80665
 
 	def loadAtmosphereModel(self, datfile, heightCol, tempCol, presCol, \
 		densCol, intType='cubic', heightInKmFlag=False):
@@ -346,7 +326,7 @@ class Planet:
 		if h>=0 and h<=self.h_thres:
 		# if altitude is within available data range, return 
 		# density data from interpolating function density_int()
-			return np.float(self.density_int(h))
+			return float(self.density_int(h))
 
 		elif h>self.h_thres:
 			# if altitude is above atmospheric 
